{
	phrases: [
		"help",
		"i've fallen",
		"good",
		"bad",
		"is",
		"is not",
		"dojo",
		"rocks",
		"subliminal",
		"hidden",
		"there",
		"are",
		"messages",
		"green",
		"tea",
		"the",
		"worst",
		"best",
		"found",
		"where",
		"why",
		"who",
		"what",
		"how",
		"I",
		"stink",
		"horse",
		"because",
		"hole",
		"$#&!",
		"ran into",
		"as the",
		"drove up to",
		"system",
		"grub",
		"golf",
		"tissue paper",
		"E minor",
		"dude",
		"on my",
		"blue screen",
		"death",
		"life"

	]
}
